api.authentication.v1.test_helpers.apikey package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.test_helpers.apikey package

## Submodules

## api.authentication.v1.test_helpers.apikey.authenticate module

`api.authentication.v1.test_helpers.apikey.authenticate.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/authenticate, respond with HTTP 403

`api.authentication.v1.test_helpers.apikey.authenticate.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/authenticate, respond with HTTP 404

`api.authentication.v1.test_helpers.apikey.authenticate.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/authenticate, respond with HTTP 200

`api.authentication.v1.test_helpers.apikey.authenticate.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/authenticate, respond with HTTP 401

## api.authentication.v1.test_helpers.apikey.initiate module

`api.authentication.v1.test_helpers.apikey.initiate.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey, respond with HTTP 403

`api.authentication.v1.test_helpers.apikey.initiate.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey, respond with HTTP 404

`api.authentication.v1.test_helpers.apikey.initiate.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey, respond with HTTP 200

`api.authentication.v1.test_helpers.apikey.initiate.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey, respond with HTTP 401

## api.authentication.v1.test_helpers.apikey.list module

`api.authentication.v1.test_helpers.apikey.list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey, respond with HTTP 403

`api.authentication.v1.test_helpers.apikey.list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey, respond with HTTP 404

`api.authentication.v1.test_helpers.apikey.list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey, respond with HTTP 200

`api.authentication.v1.test_helpers.apikey.list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey, respond with HTTP 401

## api.authentication.v1.test_helpers.apikey.renew module

`api.authentication.v1.test_helpers.apikey.renew.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/w+, respond with HTTP 403

`api.authentication.v1.test_helpers.apikey.renew.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/w+, respond with HTTP 404

`api.authentication.v1.test_helpers.apikey.renew.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/w+, respond with HTTP 200

`api.authentication.v1.test_helpers.apikey.renew.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/w+, respond with HTTP 401

## api.authentication.v1.test_helpers.apikey.revoke module

`api.authentication.v1.test_helpers.apikey.revoke.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/w+, respond with HTTP 403

`api.authentication.v1.test_helpers.apikey.revoke.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/w+, respond with HTTP 404

`api.authentication.v1.test_helpers.apikey.revoke.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/w+, respond with HTTP 200

`api.authentication.v1.test_helpers.apikey.revoke.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/apikey/w+, respond with HTTP 401

## Module contents